@@ -15,15 +15,17 @@
 //
 package org.msgpack.core
 
+import org.msgpack.core.MessagePackSpec.{createMessagePackData, toHex}
+import org.msgpack.core.buffer._
+import org.msgpack.value.ValueType
+import wvlet.airspec.AirSpec
+import wvlet.log.LogSupport
+import wvlet.log.io.IOUtil.withResource
+
 import java.io._
 import java.nio.ByteBuffer
 import java.util.Collections
-
-import org.msgpack.core.buffer._
-import org.msgpack.value.ValueType
-import xerial.core.io.IOUtil._
-
-import scala.collection.JavaConverters._
+import scala.jdk.CollectionConverters._
 import scala.util.Random
 
 object MessageUnpackerTest {
@@ -43,12 +45,12 @@ object MessageUnpackerTest {
   }
 }
 
-import MessageUnpackerTest._
+import org.msgpack.core.MessageUnpackerTest._
 
-class MessageUnpackerTest extends MessagePackSpec {
+class MessageUnpackerTest extends AirSpec with Benchmark {
 
-  val universal = MessageBuffer.allocate(0).isInstanceOf[MessageBufferU]
-  def testData: Array[Byte] = {
+  private val universal = MessageBuffer.allocate(0).isInstanceOf[MessageBufferU]
+  private def testData: Array[Byte] = {
     val out    = new ByteArrayOutputStream()
     val packer = MessagePack.newDefaultPacker(out)
 
@@ -68,9 +70,9 @@ class MessageUnpackerTest extends MessagePackSpec {
     arr
   }
 
-  val intSeq = (for (i <- 0 until 100) yield Random.nextInt()).toArray[Int]
+  private val intSeq = (for (i <- 0 until 100) yield Random.nextInt()).toArray[Int]
 
-  def testData2: Array[Byte] = {
+  private def testData2: Array[Byte] = {
     val out    = new ByteArrayOutputStream()
     val packer = MessagePack.newDefaultPacker(out);
 
@@ -86,7 +88,7 @@ class MessageUnpackerTest extends MessagePackSpec {
     arr
   }
 
-  def write(packer: MessagePacker, r: Random) {
+  private def write(packer: MessagePacker, r: Random): Unit = {
     val tpeIndex = Iterator
       .continually(r.nextInt(MessageFormat.values().length))
       .find(_ != MessageFormat.NEVER_USED.ordinal())
@@ -142,7 +144,7 @@ class MessageUnpackerTest extends MessagePackSpec {
     }
   }
 
-  def testData3(N: Int): Array[Byte] = {
+  private def testData3(N: Int): Array[Byte] = {
 
     val out    = new ByteArrayOutputStream()
     val packer = MessagePack.newDefaultPacker(out)
@@ -160,7 +162,7 @@ class MessageUnpackerTest extends MessagePackSpec {
     arr
   }
 
-  def readValue(unpacker: MessageUnpacker) {
+  private def readValue(unpacker: MessageUnpacker): Unit = {
     val f = unpacker.getNextFormat()
     f.getValueType match {
       case ValueType.ARRAY =>
@@ -181,7 +183,7 @@ class MessageUnpackerTest extends MessagePackSpec {
     }
   }
 
-  def createTempFile = {
+  private def createTempFile: File = {
     val f = File.createTempFile("msgpackTest", "msgpack")
     f.deleteOnExit
     val p = MessagePack.newDefaultPacker(new FileOutputStream(f))
@@ -190,12 +192,12 @@ class MessageUnpackerTest extends MessagePackSpec {
     f
   }
 
-  def checkFile(u: MessageUnpacker) = {
+  private def checkFile(u: MessageUnpacker): Boolean = {
     u.unpackInt shouldBe 99
     u.hasNext shouldBe false
   }
 
-  def unpackers(data: Array[Byte]): Seq[MessageUnpacker] = {
+  private def unpackers(data: Array[Byte]): Seq[MessageUnpacker] = {
     val bb = ByteBuffer.allocate(data.length)
     val db = ByteBuffer.allocateDirect(data.length)
     bb.put(data).flip()
@@ -210,7 +212,7 @@ class MessageUnpackerTest extends MessagePackSpec {
     builder.result()
   }
 
-  def unpackerCollectionWithVariousBuffers(data: Array[Byte], chunkSize: Int): Seq[MessageUnpacker] = {
+  private def unpackerCollectionWithVariousBuffers(data: Array[Byte], chunkSize: Int): Seq[MessageUnpacker] = {
     val seqBytes         = Seq.newBuilder[MessageBufferInput]
     val seqByteBuffers   = Seq.newBuilder[MessageBufferInput]
     val seqDirectBuffers = Seq.newBuilder[MessageBufferInput]
@@ -238,9 +240,9 @@ class MessageUnpackerTest extends MessagePackSpec {
     builder.result()
   }
 
-  "MessageUnpacker" should {
+  test("MessageUnpacker") {
 
-    "parse message packed data" taggedAs ("unpack") in {
+    test("parse message packed data") {
       val arr = testData
 
       for (unpacker <- unpackers(arr)) {
@@ -255,7 +257,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
     }
 
-    "skip reading values" in {
+    test("skip reading values") {
 
       for (unpacker <- unpackers(testData)) {
         var skipCount = 0
@@ -269,7 +271,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
     }
 
-    "compare skip performance" taggedAs ("skip") in {
+    test("compare skip performance") {
       val N    = 10000
       val data = testData3(N)
 
@@ -297,8 +299,7 @@ class MessageUnpackerTest extends MessagePackSpec {
 
     }
 
-    "parse int data" in {
-
+    test("parse int data") {
       debug(intSeq.mkString(", "))
 
       for (unpacker <- unpackers(testData2)) {
@@ -319,17 +320,15 @@ class MessageUnpackerTest extends MessagePackSpec {
           }
         }
 
-        ib.result shouldBe intSeq
+        ib.result() shouldBe intSeq.toSeq
         unpacker.getTotalReadBytes shouldBe testData2.length
       }
-
     }
 
-    "read data at the buffer boundary" taggedAs ("boundary") in {
-
-      trait SplitTest {
+    test("read data at the buffer boundary") {
+      trait SplitTest extends LogSupport {
         val data: Array[Byte]
-        def run {
+        def run: Unit = {
           for (unpacker <- unpackers(data)) {
             val numElems = {
               var c = 0
@@ -358,11 +357,11 @@ class MessageUnpackerTest extends MessagePackSpec {
         }
       }
 
-      new SplitTest { val data = testData      }.run
+      new SplitTest { val data = testData }.run
       new SplitTest { val data = testData3(30) }.run
     }
 
-    "read integer at MessageBuffer boundaries" taggedAs ("integer-buffer-boundary") in {
+    test("read integer at MessageBuffer boundaries") {
       val packer = MessagePack.newDefaultBufferPacker()
       (0 until 1170).foreach { i =>
         packer.packLong(0x0011223344556677L)
@@ -385,7 +384,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
     }
 
-    "read string at MessageBuffer boundaries" taggedAs ("string-buffer-boundary") in {
+    test("read string at MessageBuffer boundaries") {
       val packer = MessagePack.newDefaultBufferPacker()
       (0 until 1170).foreach { i =>
         packer.packString("hello world")
@@ -408,11 +407,11 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
     }
 
-    "be faster than msgpack-v6 skip" taggedAs ("cmp-skip") in {
+    test("be faster than msgpack-v6 skip") {
 
       trait Fixture {
         val unpacker: MessageUnpacker
-        def run {
+        def run: Unit = {
           var count = 0
           try {
             while (unpacker.hasNext) {
@@ -434,7 +433,6 @@ class MessageUnpackerTest extends MessagePackSpec {
 
       val t = time("skip performance", repeat = N) {
         block("v6") {
-          import org.msgpack.`type`.{ValueType => ValueTypeV6}
           val v6       = new org.msgpack.MessagePack()
           val unpacker = new org.msgpack.unpacker.MessagePackUnpacker(v6, new ByteArrayInputStream(data))
           var count    = 0
@@ -466,17 +464,18 @@ class MessageUnpackerTest extends MessagePackSpec {
         }
       }
 
-      t("v7-array").averageWithoutMinMax should be <= t("v6").averageWithoutMinMax
-      t("v7-array-buffer").averageWithoutMinMax should be <= t("v6").averageWithoutMinMax
-      if (!universal)
-        t("v7-direct-buffer").averageWithoutMinMax should be <= t("v6").averageWithoutMinMax
+      t("v7-array").averageWithoutMinMax <= t("v6").averageWithoutMinMax shouldBe true
+      t("v7-array-buffer").averageWithoutMinMax <= t("v6").averageWithoutMinMax shouldBe true
+      if (!universal) {
+        t("v7-direct-buffer").averageWithoutMinMax <= t("v6").averageWithoutMinMax shouldBe true
+      }
     }
 
     import org.msgpack.`type`.{ValueType => ValueTypeV6}
 
-    "be faster than msgpack-v6 read value" taggedAs ("cmp-unpack") in {
+    test("be faster than msgpack-v6 read value") {
 
-      def readValueV6(unpacker: org.msgpack.unpacker.MessagePackUnpacker) {
+      def readValueV6(unpacker: org.msgpack.unpacker.MessagePackUnpacker): Unit = {
         val vt = unpacker.getNextType()
         vt match {
           case ValueTypeV6.ARRAY =>
@@ -508,7 +507,7 @@ class MessageUnpackerTest extends MessagePackSpec {
 
       val buf = new Array[Byte](8192)
 
-      def readValue(unpacker: MessageUnpacker) {
+      def readValue(unpacker: MessageUnpacker): Unit = {
         val f  = unpacker.getNextFormat
         val vt = f.getValueType
         vt match {
@@ -540,7 +539,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
       trait Fixture {
         val unpacker: MessageUnpacker
-        def run {
+        def run: Unit = {
           var count = 0
           try {
             while (unpacker.hasNext) {
@@ -598,12 +597,12 @@ class MessageUnpackerTest extends MessagePackSpec {
       if (t("v7-array-buffer").averageWithoutMinMax > t("v6").averageWithoutMinMax) {
         warn(s"v7-array-buffer ${t("v7-array-buffer").averageWithoutMinMax} is slower than v6 ${t("v6").averageWithoutMinMax}")
       }
-      if (!universal)
-        t("v7-direct-buffer").averageWithoutMinMax should be <= t("v6").averageWithoutMinMax
-
+      if (!universal) {
+        t("v7-direct-buffer").averageWithoutMinMax <= t("v6").averageWithoutMinMax shouldBe true
+      }
     }
 
-    "be faster for reading binary than v6" taggedAs ("cmp-binary") in {
+    test("be faster for reading binary than v6") {
 
       val bos    = new ByteArrayOutputStream()
       val packer = MessagePack.newDefaultPacker(bos)
@@ -618,7 +617,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       trait Fixture {
         val unpacker: MessageUnpacker
         val loop: Int
-        def run {
+        def run: Unit = {
           var i = 0
           try {
             while (i < loop) {
@@ -629,7 +628,7 @@ class MessageUnpackerTest extends MessagePackSpec {
             }
           } finally unpacker.close()
         }
-        def runRef {
+        def runRef: Unit = {
           var i = 0
           try {
             while (i < loop) {
@@ -702,37 +701,37 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
     }
 
-    "read payload as a reference" taggedAs ("ref") in {
+    test("read payload as a reference") {
 
       val dataSizes =
         Seq(0, 1, 5, 8, 16, 32, 128, 256, 1024, 2000, 10000, 100000)
 
       for (s <- dataSizes) {
-        When(f"data size is $s%,d")
-        val data = new Array[Byte](s)
-        Random.nextBytes(data)
-        val b      = new ByteArrayOutputStream()
-        val packer = MessagePack.newDefaultPacker(b)
-        packer.packBinaryHeader(s)
-        packer.writePayload(data)
-        packer.close()
+        test(f"data size is $s%,d") {
+          val data = new Array[Byte](s)
+          Random.nextBytes(data)
+          val b      = new ByteArrayOutputStream()
+          val packer = MessagePack.newDefaultPacker(b)
+          packer.packBinaryHeader(s)
+          packer.writePayload(data)
+          packer.close()
 
-        for (unpacker <- unpackers(b.toByteArray)) {
-          val len = unpacker.unpackBinaryHeader()
-          len shouldBe s
-          val ref = unpacker.readPayloadAsReference(len)
-          unpacker.close()
-          ref.size() shouldBe s
-          val stored = new Array[Byte](len)
-          ref.getBytes(0, stored, 0, len)
+          for (unpacker <- unpackers(b.toByteArray)) {
+            val len = unpacker.unpackBinaryHeader()
+            len shouldBe s
+            val ref = unpacker.readPayloadAsReference(len)
+            unpacker.close()
+            ref.size() shouldBe s
+            val stored = new Array[Byte](len)
+            ref.getBytes(0, stored, 0, len)
 
-          stored shouldBe data
+            stored shouldBe data
+          }
         }
       }
-
     }
 
-    "reset the internal states" taggedAs ("reset") in {
+    test("reset the internal states") {
 
       val data = intSeq
       val b    = createMessagePackData(packer => data foreach packer.packInt)
@@ -743,7 +742,7 @@ class MessageUnpackerTest extends MessagePackSpec {
           unpacked += unpacker.unpackInt()
         }
         unpacker.close
-        unpacked.result shouldBe data
+        unpacked.result() shouldBe data
 
         val data2 = intSeq
         val b2    = createMessagePackData(packer => data2 foreach packer.packInt)
@@ -754,7 +753,7 @@ class MessageUnpackerTest extends MessagePackSpec {
           unpacked2 += unpacker.unpackInt()
         }
         unpacker.close
-        unpacked2.result shouldBe data2
+        unpacked2.result() shouldBe data2
 
         // reused the buffer input instance
         bi.reset(b2)
@@ -764,12 +763,12 @@ class MessageUnpackerTest extends MessagePackSpec {
           unpacked3 += unpacker.unpackInt()
         }
         unpacker.close
-        unpacked3.result shouldBe data2
+        unpacked3.result() shouldBe data2
       }
 
     }
 
-    "improve the performance via reset method" taggedAs ("reset-arr") in {
+    test("improve the performance via reset method") {
 
       val out    = new ByteArrayOutputStream
       val packer = MessagePack.newDefaultPacker(out)
@@ -821,7 +820,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       // t("reuse-array-input").averageWithoutMinMax should be <= t("no-buffer-reset").averageWithoutMinMax
     }
 
-    "reset ChannelBufferInput" in {
+    test("reset ChannelBufferInput") {
       val f0 = createTempFile
       val u  = MessagePack.newDefaultUnpacker(new FileInputStream(f0).getChannel)
       checkFile(u)
@@ -833,7 +832,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       u.close
     }
 
-    "reset InputStreamBufferInput" in {
+    test("reset InputStreamBufferInput") {
       val f0 = createTempFile
       val u  = MessagePack.newDefaultUnpacker(new FileInputStream(f0))
       checkFile(u)
@@ -845,7 +844,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       u.close
     }
 
-    "unpack large string data" taggedAs ("large-string") in {
+    test("unpack large string data") {
       def createLargeData(stringLength: Int): Array[Byte] = {
         val out    = new ByteArrayOutputStream()
         val packer = MessagePack.newDefaultPacker(out)
@@ -874,7 +873,7 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
     }
 
-    "unpack string crossing end of buffer" in {
+    test("unpack string crossing end of buffer") {
       def check(expected: String, strLen: Int) = {
         val bytes = new Array[Byte](strLen)
         val out   = new ByteArrayOutputStream
@@ -910,12 +909,15 @@ class MessageUnpackerTest extends MessagePackSpec {
       }
     }
 
-    "read value length at buffer boundary" taggedAs ("number-boundary") in {
+    test("read value length at buffer boundary") {
       val input = new SplitMessageBufferInput(
-        Array(Array[Byte](MessagePack.Code.STR16),
-              Array[Byte](0x00),
-              Array[Byte](0x05), // STR16 length at the boundary
-              "hello".getBytes(MessagePack.UTF8)))
+        Array(
+          Array[Byte](MessagePack.Code.STR16),
+          Array[Byte](0x00),
+          Array[Byte](0x05), // STR16 length at the boundary
+          "hello".getBytes(MessagePack.UTF8)
+        )
+      )
       readTest(input)
 
       val input2 = new SplitMessageBufferInput(
@@ -925,7 +927,8 @@ class MessageUnpackerTest extends MessagePackSpec {
           Array[Byte](0x00, 0x00),
           Array[Byte](0x05), // STR32 length at the boundary
           "hello".getBytes(MessagePack.UTF8)
-        ))
+        )
+      )
       readTest(input2)
     }
   }
