@@ -270,7 +270,8 @@ public class MessagePackGenerator
         if (failedToPackAsBI) {
             double doubleValue = decimal.doubleValue();
             //Check to make sure this BigDecimal can be represented as a double
-            if (!decimal.stripTrailingZeros().toEngineeringString().equals(BigDecimal.valueOf(doubleValue).toEngineeringString())) {
+            if (!decimal.stripTrailingZeros().toEngineeringString().equals(
+                    BigDecimal.valueOf(doubleValue).stripTrailingZeros().toEngineeringString())) {
                 throw new IllegalArgumentException("MessagePack cannot serialize a BigDecimal that can't be represented as double. " + decimal);
             }
             messagePacker.packDouble(doubleValue);
